@@ -25,8 +25,8 @@
 #include "event.h"
 #include "filter.h"
 #include "format.h"
-#include "index.h"
 #include "ghostpad.h"
+#include "index.h"
 #include "indexfactory.h"
 #include "interface.h"
 #include "iterator.h"
@@ -47,11 +47,12 @@
 #include "taglist.h"
 #include "tagsetter.h"
 #include "task.h"
+#include "taskpool.h"
 #include "urihandler.h"
 #include "value.h"
 #include "xml.h"
-#include "basesrc.h"
 #include "basesink.h"
+#include "basesrc.h"
 #include "basetransform.h"
 #include "pushsrc.h"
 #include "audioclock.h"
@@ -73,15 +74,17 @@
 #include "tuner.h"
 #include "tunerchannel.h"
 #include "tunernorm.h"
+#include "typefind.h"
+#include "typefindfactory.h"
 #include "videoorientation.h"
 #include "xoverlay.h"
 #include "capsfilter.h"
-#include "fakesrc.h"
 #include "fakesink.h"
+#include "fakesrc.h"
 #include "fdsink.h"
 #include "fdsrc.h"
-#include "filesrc.h"
 #include "filesink.h"
+#include "filesrc.h"
 #include "identity.h"
 #include "multiqueue.h"
 #include "queue.h"
@@ -97,6 +100,7 @@
 #include "cdparanoiasrc.h"
 #include "clockoverlay.h"
 #include "decodebin.h"
+#include "decodebin2.h"
 #include "ffmpegcolorspace.h"
 #include "gdpdepay.h"
 #include "gdppay.h"
@@ -104,17 +108,22 @@
 #include "giosrc.h"
 #include "giostreamsink.h"
 #include "giostreamsrc.h"
+#include "multifdsink.h"
 #include "oggdemux.h"
 #include "oggmux.h"
+#include "playbin.h"
 #include "playbin2.h"
-#include "tcpclientsrc.h"
 #include "tcpclientsink.h"
+#include "tcpclientsrc.h"
+#include "tcpserversink.h"
 #include "tcpserversrc.h"
 #include "textoverlay.h"
 #include "textrender.h"
 #include "theoradec.h"
 #include "theoraenc.h"
+#include "theoraparse.h"
 #include "timeoverlay.h"
+#include "uridecodebin.h"
 #include "videorate.h"
 #include "videoscale.h"
 #include "videotestsrc.h"
@@ -156,6 +165,7 @@ GType gst_clock_get_type(void);
 GType gst_clock_overlay_get_type(void);
 GType gst_color_balance_channel_get_type(void);
 GType gst_decode_bin_get_type(void);
+GType gst_decode_bin2_get_type(void);
 GType gst_element_get_type(void);
 GType gst_element_factory_get_type(void);
 GType gst_fake_sink_get_type(void);
@@ -177,6 +187,7 @@ GType gst_index_get_type(void);
 GType gst_index_factory_get_type(void);
 GType gst_mixer_options_get_type(void);
 GType gst_mixer_track_get_type(void);
+GType gst_multi_fd_sink_get_type(void);
 GType gst_multi_queue_get_type(void);
 GType gst_object_get_type(void);
 GType gst_ogg_demux_get_type(void);
@@ -184,6 +195,7 @@ GType gst_ogg_mux_get_type(void);
 GType gst_pad_get_type(void);
 GType gst_pad_template_get_type(void);
 GType gst_pipeline_get_type(void);
+GType gst_play_bin_get_type(void);
 GType gst_play_bin2_get_type(void);
 GType gst_plugin_get_type(void);
 GType gst_plugin_feature_get_type(void);
@@ -196,15 +208,20 @@ GType gst_tcp_client_sink_get_type(void);
 GType gst_tcp_client_src_get_type(void);
 GType gst_tcp_server_src_get_type(void);
 GType gst_task_get_type(void);
+GType gst_task_pool_get_type(void);
+GType gst_tcp_server_sink_get_type(void);
 GType gst_tee_get_type(void);
 GType gst_text_overlay_get_type(void);
 GType gst_text_render_get_type(void);
 GType gst_theora_dec_get_type(void);
 GType gst_theora_enc_get_type(void);
+GType gst_theora_parse_get_type(void);
 GType gst_time_overlay_get_type(void);
 GType gst_tuner_channel_get_type(void);
 GType gst_tuner_norm_get_type(void);
 GType gst_type_find_element_get_type(void);
+GType gst_type_find_factory_get_type(void);
+GType gst_uri_decode_bin_get_type(void);
 GType gst_video_rate_get_type(void);
 GType gst_video_scale_get_type(void);
 GType gst_video_sink_get_type(void);
@@ -256,6 +273,7 @@ namespace Gst {  class Clock_Class { public: static Glib::ObjectBase* wrap_new(G
 namespace Gst {  class ClockOverlay_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class ColorBalanceChannel_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class DecodeBin_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gst {  class DecodeBin2_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class Element_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class ElementFactory_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class FakeSink_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -277,6 +295,7 @@ namespace Gst {  class Index_Class { public: static Glib::ObjectBase* wrap_new(G
 namespace Gst {  class IndexFactory_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class MixerOptions_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class MixerTrack_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gst {  class MultiFdSink_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class MultiQueue_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class Object_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class OggDemux_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -284,6 +303,7 @@ namespace Gst {  class OggMux_Class { public: static Glib::ObjectBase* wrap_new(
 namespace Gst {  class Pad_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class PadTemplate_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class Pipeline_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gst {  class PlayBin_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class PlayBin2_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class Plugin_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class PluginFeature_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -296,15 +316,20 @@ namespace Gst {  class TCPClientSink_Class { public: static Glib::ObjectBase* wr
 namespace Gst {  class TCPClientSrc_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class TCPServerSrc_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class Task_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gst {  class TaskPool_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gst {  class TcpServerSink_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class Tee_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class TextOverlay_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class TextRender_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class TheoraDec_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class TheoraEnc_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gst {  class TheoraParse_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class TimeOverlay_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class TunerChannel_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class TunerNorm_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class TypeFindElement_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gst {  class TypeFindFactory_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gst {  class UriDecodeBin_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class VideoRate_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class VideoScale_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class VideoSink_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -356,6 +381,7 @@ void wrap_init()
   Glib::wrap_register(gst_clock_overlay_get_type(), &Gst::ClockOverlay_Class::wrap_new);
   Glib::wrap_register(gst_color_balance_channel_get_type(), &Gst::ColorBalanceChannel_Class::wrap_new);
   Glib::wrap_register(gst_decode_bin_get_type(), &Gst::DecodeBin_Class::wrap_new);
+  Glib::wrap_register(gst_decode_bin2_get_type(), &Gst::DecodeBin2_Class::wrap_new);
   Glib::wrap_register(gst_element_get_type(), &Gst::Element_Class::wrap_new);
   Glib::wrap_register(gst_element_factory_get_type(), &Gst::ElementFactory_Class::wrap_new);
   Glib::wrap_register(gst_fake_sink_get_type(), &Gst::FakeSink_Class::wrap_new);
@@ -377,6 +403,7 @@ void wrap_init()
   Glib::wrap_register(gst_index_factory_get_type(), &Gst::IndexFactory_Class::wrap_new);
   Glib::wrap_register(gst_mixer_options_get_type(), &Gst::MixerOptions_Class::wrap_new);
   Glib::wrap_register(gst_mixer_track_get_type(), &Gst::MixerTrack_Class::wrap_new);
+  Glib::wrap_register(gst_multi_fd_sink_get_type(), &Gst::MultiFdSink_Class::wrap_new);
   Glib::wrap_register(gst_multi_queue_get_type(), &Gst::MultiQueue_Class::wrap_new);
   Glib::wrap_register(gst_object_get_type(), &Gst::Object_Class::wrap_new);
   Glib::wrap_register(gst_ogg_demux_get_type(), &Gst::OggDemux_Class::wrap_new);
@@ -384,6 +411,7 @@ void wrap_init()
   Glib::wrap_register(gst_pad_get_type(), &Gst::Pad_Class::wrap_new);
   Glib::wrap_register(gst_pad_template_get_type(), &Gst::PadTemplate_Class::wrap_new);
   Glib::wrap_register(gst_pipeline_get_type(), &Gst::Pipeline_Class::wrap_new);
+  Glib::wrap_register(gst_play_bin_get_type(), &Gst::PlayBin_Class::wrap_new);
   Glib::wrap_register(gst_play_bin2_get_type(), &Gst::PlayBin2_Class::wrap_new);
   Glib::wrap_register(gst_plugin_get_type(), &Gst::Plugin_Class::wrap_new);
   Glib::wrap_register(gst_plugin_feature_get_type(), &Gst::PluginFeature_Class::wrap_new);
@@ -396,15 +424,20 @@ void wrap_init()
   Glib::wrap_register(gst_tcp_client_src_get_type(), &Gst::TCPClientSrc_Class::wrap_new);
   Glib::wrap_register(gst_tcp_server_src_get_type(), &Gst::TCPServerSrc_Class::wrap_new);
   Glib::wrap_register(gst_task_get_type(), &Gst::Task_Class::wrap_new);
+  Glib::wrap_register(gst_task_pool_get_type(), &Gst::TaskPool_Class::wrap_new);
+  Glib::wrap_register(gst_tcp_server_sink_get_type(), &Gst::TcpServerSink_Class::wrap_new);
   Glib::wrap_register(gst_tee_get_type(), &Gst::Tee_Class::wrap_new);
   Glib::wrap_register(gst_text_overlay_get_type(), &Gst::TextOverlay_Class::wrap_new);
   Glib::wrap_register(gst_text_render_get_type(), &Gst::TextRender_Class::wrap_new);
   Glib::wrap_register(gst_theora_dec_get_type(), &Gst::TheoraDec_Class::wrap_new);
   Glib::wrap_register(gst_theora_enc_get_type(), &Gst::TheoraEnc_Class::wrap_new);
+  Glib::wrap_register(gst_theora_parse_get_type(), &Gst::TheoraParse_Class::wrap_new);
   Glib::wrap_register(gst_time_overlay_get_type(), &Gst::TimeOverlay_Class::wrap_new);
   Glib::wrap_register(gst_tuner_channel_get_type(), &Gst::TunerChannel_Class::wrap_new);
   Glib::wrap_register(gst_tuner_norm_get_type(), &Gst::TunerNorm_Class::wrap_new);
   Glib::wrap_register(gst_type_find_element_get_type(), &Gst::TypeFindElement_Class::wrap_new);
+  Glib::wrap_register(gst_type_find_factory_get_type(), &Gst::TypeFindFactory_Class::wrap_new);
+  Glib::wrap_register(gst_uri_decode_bin_get_type(), &Gst::UriDecodeBin_Class::wrap_new);
   Glib::wrap_register(gst_video_rate_get_type(), &Gst::VideoRate_Class::wrap_new);
   Glib::wrap_register(gst_video_scale_get_type(), &Gst::VideoScale_Class::wrap_new);
   Glib::wrap_register(gst_video_sink_get_type(), &Gst::VideoSink_Class::wrap_new);
@@ -444,6 +477,7 @@ void wrap_init()
   Gst::ClockOverlay::get_type();
   Gst::ColorBalanceChannel::get_type();
   Gst::DecodeBin::get_type();
+  Gst::DecodeBin2::get_type();
   Gst::Element::get_type();
   Gst::ElementFactory::get_type();
   Gst::FakeSink::get_type();
@@ -465,6 +499,7 @@ void wrap_init()
   Gst::IndexFactory::get_type();
   Gst::MixerOptions::get_type();
   Gst::MixerTrack::get_type();
+  Gst::MultiFdSink::get_type();
   Gst::MultiQueue::get_type();
   Gst::Object::get_type();
   Gst::OggDemux::get_type();
@@ -472,6 +507,7 @@ void wrap_init()
   Gst::Pad::get_type();
   Gst::PadTemplate::get_type();
   Gst::Pipeline::get_type();
+  Gst::PlayBin::get_type();
   Gst::PlayBin2::get_type();
   Gst::Plugin::get_type();
   Gst::PluginFeature::get_type();
@@ -484,15 +520,20 @@ void wrap_init()
   Gst::TCPClientSrc::get_type();
   Gst::TCPServerSrc::get_type();
   Gst::Task::get_type();
+  Gst::TaskPool::get_type();
+  Gst::TcpServerSink::get_type();
   Gst::Tee::get_type();
   Gst::TextOverlay::get_type();
   Gst::TextRender::get_type();
   Gst::TheoraDec::get_type();
   Gst::TheoraEnc::get_type();
+  Gst::TheoraParse::get_type();
   Gst::TimeOverlay::get_type();
   Gst::TunerChannel::get_type();
   Gst::TunerNorm::get_type();
   Gst::TypeFindElement::get_type();
+  Gst::TypeFindFactory::get_type();
+  Gst::UriDecodeBin::get_type();
   Gst::VideoRate::get_type();
   Gst::VideoScale::get_type();
   Gst::VideoSink::get_type();
